
<div align="center">
 <h1>youtube-analyzer</h1>

![Versão](https://img.shields.io/badge/version-1.3-orange)
![Licença](https://img.shields.io/badge/license-MIT-orange)

<br><br>
<i>Obtenha detalhes completos de vídeos do YouTube com esta biblioteca incrível!</i>
<br>
</div>

### Funcionalidades
- [x] Obter detalhes de um vídeo
- [x] Obter legendas
- [x] Tradução de legendas
- [x] Analisar playlists
- [x] Obter detalhes de URIs de vídeos
- [x] Downloads de áudios e vídeos

Acesse a [Documentação aqui](https://github.com/PauloCesar-dev404/youtube_analyzer/blob/main/Docs/document.md)

---

### Contribuições
Se tiver dúvidas ou sugestões, abra uma [issue aqui](https://github.com/PauloCesar-dev404/youtube_analyzer/issues).

---
